# AIGC Detector

![publish](https://github.com/crazyurus/aigc-detector/actions/workflows/publish.yaml/badge.svg)
[![GPL-3.0](https://img.shields.io/badge/license-GPL3-blue.svg)](LICENSE)
[![npm](https://badgen.net/npm/v/aigc-detector)](https://www.npmjs.com/package/aigc-detector)
[![npm dependents](https://badgen.net/npm/dependents/aigc-detector)](https://www.npmjs.com/package/aigc-detector?activeTab=dependents)
[![npm downloads](https://badgen.net/npm/dt/aigc-detector)](https://www.npmjs.com/package/aigc-detector)

Detect if content is generated by AI. Provides command line tools and use in Node.js.


## Usage

You need to configure the large model platform and its API Key that the tool depends on. Currently, the following platforms are supported:

- [百川智能](https://platform.baichuan-ai.com/)
- [MiniMax](https://www.minimaxi.com/)
- [Moonshot](https://platform.moonshot.cn/)
- [OpenAI](https://platform.openai.com/)
- [通义千问](https://dashscope.console.aliyun.com/)
- [智谱清言](https://open.bigmodel.cn/)

You can log in to the above platform to apply for an API Key.

### Command Line Tools

First, install globally:

```sh
$ npm install aigc-detector -g
```

Then, you need to configure the API Key you have applied for in the tool. For example:

```sh
$ aigc-detector config -p moonshot -k sk-GQz***************************************8UnlrT
```

Finally, tell us the content that needs to be detected and we can proceed.

```sh
$ aigc-detector detect [CONTENT]
```

For more ways to use `aigc-detector`, please refer to the help command.

```sh
$ aigc-detector help
```

### Using in Node.js

First, install in your project:

```sh
$ npm install aigc-detector
```

Then, you need to configure the API Key you have applied to initialize. For example:

```js
import { AIGC, Platform } from 'aigc-detector';

const detector = new AIGC({
  apiKey: 'sk-GQz***************************************8UnlrT',
  platform: Platform.Moonshot,
});
```

Finally, call the `detect` method and give the content that needs to be detected.

```js
const { probability, reason } = await detector.detect(content);
```

- `probability` is the probability that the content is generated by AI
- `reason` is the reason why the content is generated by AI

## Develop

You need to execute `npm link` to create a local debugging cli tool, and then you can use `aigc-detector-dev` for debugging. For example:

```sh
$ aigc-detector-dev config
```

## License

[GPL-3.0](./LICENSE)