import { Command, loadHelpClass } from '@oclif/core';
import chalk from 'chalk';
import ConfigManager from "../manager/config.js";
import FileManager from "../manager/file.js";
import NetworkManager from "../manager/network.js";
class BaseCommand extends Command {
  configManager;
  fileManager;
  networkManager;
  constructor(argv, config) {
    super(argv, config);
    this.configManager = new ConfigManager(this.config.configDir);
    this.fileManager = new FileManager();
    this.networkManager = new NetworkManager(this.config);
  }
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  async catch(error) {
    process.exitCode = process.exitCode ?? error.exitCode ?? 1;
    if (this.jsonEnabled()) {
      this.logJson(this.toErrorJson(error));
    } else {
      this.error(error.message, {
        code: error.exitCode,
        exit: process.exitCode
      });
    }
  }
  list(label, content) {
    this.log(chalk.cyan(label) + ': ' + content);
  }
  async showHelp() {
    const Help = await loadHelpClass(this.config);
    const help = new Help(this.config);
    await help.showHelp(this.argv);
  }
  success(text) {
    const bang = chalk.green('✓');
    this.log(bang + ' ' + text);
  }
}
export default BaseCommand;