import path from 'node:path';
import { getEnvConfig } from "../../core/env.js";
import FileManager from "./file.js";
import encryptMiddleware from "./middlewares/encrypt.js";
class ConfigManager {
  configDirectory;
  configPath;
  fileManager;
  constructor(configDirectory) {
    this.configDirectory = configDirectory;
    this.configPath = path.join(configDirectory, 'settings');
    this.fileManager = new FileManager([encryptMiddleware]);
  }
  async getAll() {
    const result = getEnvConfig();
    if (Object.keys(result).length > 0) {
      return result;
    }
    try {
      const config = await this.fileManager.readFile(this.configPath);
      return JSON.parse(config.toString());
    } catch {
      return {};
    }
  }
  async getItem(key) {
    const config = await this.getAll();
    return config[key];
  }
  async setItem(key, value) {
    const config = await this.getAll();
    config[key] = value;
    if (!(await this.fileManager.isFileExist(this.configDirectory))) {
      await this.fileManager.makeDirectory(this.configDirectory);
    }
    await this.fileManager.writeFile(this.configPath, JSON.stringify(config, null, 2));
  }
}
export default ConfigManager;