import fs from 'node:fs/promises';
class FileManager {
  middlewares = [];
  constructor(middlewares) {
    if (middlewares) {
      this.middlewares = middlewares;
    }
  }
  async isFileExist(path) {
    try {
      await fs.access(path);
      return true;
    } catch {
      return false;
    }
  }
  async makeDirectory(path) {
    await fs.mkdir(path);
  }
  async readFile(path) {
    const content = await fs.readFile(path);
    let originContent = content.toString();
    for (const middleware of this.middlewares) {
      originContent = middleware.read(originContent);
    }
    return originContent;
  }
  async writeFile(path, content) {
    let originContent = content;
    for (const middleware of this.middlewares) {
      originContent = middleware.write(originContent);
    }
    await fs.writeFile(path, originContent);
  }
}
export default FileManager;