import { ChatPromptTemplate, HumanMessagePromptTemplate, SystemMessagePromptTemplate } from '@langchain/core/prompts';
import { ChatOpenAI } from '@langchain/openai';
import { LLMChain } from 'langchain/chains';
import { PROMPT } from "../const.js";
class Platform {
  temperature = 0.7;
  getChatModel(apiKey) {
    return new ChatOpenAI({
      apiKey,
      configuration: {
        baseURL: `https://${this.server}/v1`
      },
      frequencyPenalty: 1,
      model: this.model,
      temperature: this.temperature
    });
  }
  getPrompt() {
    return ChatPromptTemplate.fromMessages([SystemMessagePromptTemplate.fromTemplate(PROMPT), HumanMessagePromptTemplate.fromTemplate('Here is what needs to be evaluated: \n{content}')]);
  }
  async invoke(content, apiKey) {
    const prompt = this.getPrompt();
    const chain = new LLMChain({
      llm: this.getChatModel(apiKey),
      prompt
    });
    const result = await chain.invoke({
      content
    });
    return result.text;
  }
}
export default Platform;